summaryrefslogtreecommitdiffstats
path: root/libkdegames/kchatbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kchatbase.h')
-rw-r--r--libkdegames/kchatbase.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkdegames/kchatbase.h b/libkdegames/kchatbase.h
index 77a6ed4f..892e5859 100644
--- a/libkdegames/kchatbase.h
+++ b/libkdegames/kchatbase.h
@@ -187,12 +187,12 @@ class KDE_EXPORT KChatBase : public TQFrame
TQ_OBJECT
public:
/**
* @param tqparent The tqparent widget for this widget.
* @param noComboBox If true then the combo box where the player can
* choose where to send messages to (either globally or just to some
* players) will not be added.
**/
- KChatBase(TQWidget* tqparent, bool noComboBox = false);
+ KChatBase(TQWidget* parent, bool noComboBox = false);
/**
* Destruct the KChatBase object
@@ -187,12 +187,12 @@ class KDE_EXPORT KChatBase : public TQFrame
public:
/**
- * @param tqparent The tqparent widget for this widget.
+ * @param parent The parent widget for this widget.
* @param noComboBox If true then the combo box where the player can
* choose where to send messages to (either globally or just to some